Module prelude

Module prelude 

The prelude contains all definitions thought to be needed by typical users of the library

Re-exports

pub use super::deserialize_slice_as_vec;
pub use super::get_result_schema;
pub use super::get_schema;
pub use super::introspect_item;
pub use super::load;
pub use super::load_file;
pub use super::load_file_noschema;
pub use super::load_from_mem;
pub use super::load_noschema;
pub use super::save;
pub use super::save_file;
pub use super::save_file_noschema;
pub use super::save_noschema;
pub use super::save_to_mem;
pub use super::AbiRemoved;
pub use super::Canary1;
pub use super::Deserialize;
pub use super::Deserializer;
pub use super::Field;
pub use super::Introspect;
pub use super::IntrospectItem;
pub use super::IntrospectedElementKey;
pub use super::IntrospectionResult;
pub use super::Introspector;
pub use super::IntrospectorNavCommand;
pub use super::IsPacked;
pub use super::Packed;
pub use super::Removed;
pub use super::SavefileError;
pub use super::Schema;
pub use super::SchemaEnum;
pub use super::SchemaPrimitive;
pub use super::SchemaStruct;
pub use super::Serialize;
pub use super::Serializer;
pub use super::Variant;
pub use super::WithSchema;
pub use super::WithSchemaContext;
pub use super::AbiMethod;
pub use super::AbiMethodArgument;
pub use super::AbiMethodInfo;
pub use super::AbiTraitDefinition;
pub use super::ReceiverType;

Macros

offset_of
Expands to the offset in bytes of a field from the beginning of the given type.
offset_of_tuple
Calculates the offset of the specified field from the start of the tuple.
span_of
Produces a range instance representing the sub-slice containing the specified member.

Enums

LittleEndian
Defines little-endian serialization.

Traits

ReadBytesExt
Extends Read with methods for reading numbers. (For std::io.)

Derive Macros

Packed
Savefile
SavefileIntrospectOnly
SavefileNoIntrospect